Module envelope

Module envelope 

Envelope encryption with key versioning support.

Envelope encryption wraps data with a version header to support key rotation. The ciphertext format includes the key version, allowing decryption with the correct key from the key ring.

Structs

EnvelopeEncryptor
Envelope encryptor with key rotation support.