pub struct EncryptionKey { /* private fields */ }Expand description
A secure encryption key that is zeroed on drop.
Implementations
Sourceimpl EncryptionKey
impl EncryptionKey
Sourcepub fn generate(length: usize) -> Self
pub fn generate(length: usize) -> Self
Generate a random encryption key of the specified length.
Sourcepub fn from_base64(encoded: &str) -> CryptoResult<Self>
pub fn from_base64(encoded: &str) -> CryptoResult<Self>
Create a key from a base64-encoded string.